import type { NgForageOptions } from '../config';
import { CacheConfigurable } from '../config';
import { NgForage } from '../main';
import type { CachedItem } from './cached-item';
import * as i0 from "@angular/core";
/**
 * An extension of {@link NgForage} which adds expiration support
 */
export declare class NgForageCache extends NgForage implements CacheConfigurable {
    /**
     * Cache time in milliseconds
     * @default 300000
     */
    get cacheTime(): number;
    set cacheTime(t: number);
    /** @inheritDoc */
    clone(config?: NgForageOptions): NgForageCache;
    /**
     * Retrieve data
     * @param key Data key
     */
    getCached<T>(key: string): Promise<CachedItem<T>>;
    /**
     * Remove data
     * @param key Data key
     */
    removeCached(key: string): Promise<void>;
    /**
     * Set data
     * @param key Data key
     * @param data Data to set
     * @param [cacheTime] Override cache set in {@link CacheConfigurable#cacheTime global or instance config}.
     */
    setCached<T>(key: string, data: T, cacheTime?: number): Promise<T>;
    /** @internal */
    toJSON(): NgForageOptions;
    static ɵfac: i0.ɵɵFactoryDeclaration<NgForageCache, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<NgForageCache>;
}
