import 'localforage';
import type { DriverType } from '../misc/driver-type.type';
import type { BaseConfigurable } from './base-configurable';
import type { CacheConfigurable } from './cache-configurable';
import type { NgForageOptions } from './ng-forage-options';
import * as i0 from "@angular/core";
/** @internal */
declare const $defaultConfig: unique symbol;
/**
 * Global/default configuration
 */
export declare class NgForageConfig implements BaseConfigurable, CacheConfigurable {
    /** @internal */
    private readonly [$defaultConfig];
    constructor(conf: NgForageOptions);
    /**
     * Cache time in milliseconds
     * @default 300000
     */
    get cacheTime(): number;
    set cacheTime(t: number);
    /**
     * Get the compiled configuration
     */
    get config(): NgForageOptions;
    /**
     * A description of the database, essentially for developer usage.
     * @default
     */
    get description(): string;
    set description(v: string);
    /**
     * The preferred driver(s) to use.
     */
    get driver(): DriverType | DriverType[];
    set driver(v: DriverType | DriverType[]);
    /**
     * The name of the database. May appear during storage limit prompts. Useful to use the name of your app here.
     * In localStorage, this is used as a key prefix for all keys stored in localStorage.
     * @default ngForage
     */
    get name(): string;
    set name(v: string);
    /**
     * The size of the database in bytes. Used only in WebSQL for now.
     * @default 4980736
     */
    get size(): number;
    set size(v: number);
    /**
     * The name of the datastore.
     * In IndexedDB this is the dataStore,
     * in WebSQL this is the name of the key/value table in the database.
     * Must be alphanumeric, with underscores.
     * Any non-alphanumeric characters will be converted to underscores.
     * @default ng_forage
     */
    get storeName(): string;
    set storeName(v: string);
    /**
     * The version of your database. May be used for upgrades in the future; currently unused.
     * @default 1.0
     */
    get version(): number;
    set version(v: number);
    /**
     * Bulk-set configuration options
     * @param opts The configuration
     */
    configure(opts: NgForageOptions): this;
    /**
     * Define a driver
     *
     * You’ll want to make sure you accept a callback argument and that you pass the same arguments to callbacks as the
     * default drivers do. You’ll also want to resolve or reject promises.
     * Check any of the {@link https://github.com/mozilla/localForage/tree/master/src/drivers default drivers}
     * for an idea of how to implement your own, custom driver.
     * @param spec Driver spec
     */
    defineDriver(spec: LocalForageDriver): Promise<void>;
    /** @internal */
    toJSON(): NgForageOptions;
    toString(): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<NgForageConfig, [{ optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<NgForageConfig>;
}
export {};
